Bug 1248399 - Update browser.snippets.geoURL and handling code to use MLS instead of geodude. r=giorgos,grisha draft
authorMargaret Leibovic <margaret.leibovic@gmail.com>
Tue, 22 Mar 2016 15:50:43 -0400
changeset 343491 5ecb60dc5ee6dedf651bf1ad03f76b65b03ffcd8
parent 343487 5453ae837f6a9394f01f2219c3998098f23a41fb
child 516785 a913835d4ab9d60e4647004c6f5226baf65d1d94
push id13635
push usermleibovic@mozilla.com
push dateTue, 22 Mar 2016 19:55:46 +0000
reviewersgiorgos, grisha
bugs1248399
milestone48.0a1
Bug 1248399 - Update browser.snippets.geoURL and handling code to use MLS instead of geodude. r=giorgos,grisha MozReview-Commit-ID: wm4ZYbRCcq
mobile/android/app/mobile.js
--- a/mobile/android/app/mobile.js
+++ b/mobile/android/app/mobile.js
@@ -859,18 +859,19 @@ pref("snav.enabled", true);
 // This url, if changed, MUST continue to point to an https url. Pulling arbitrary content to inject into
 // this page over http opens us up to a man-in-the-middle attack that we'd rather not face. If you are a downstream
 // repackager of this code using an alternate snippet url, please keep your users safe
 pref("browser.snippets.updateUrl", "https://snippets.cdn.mozilla.net/json/%SNIPPETS_VERSION%/%NAME%/%VERSION%/%APPBUILDID%/%BUILD_TARGET%/%LOCALE%/%CHANNEL%/%OS_VERSION%/%DISTRIBUTION%/%DISTRIBUTION_VERSION%/");
 
 // How frequently we check for new snippets, in seconds (1 day)
 pref("browser.snippets.updateInterval", 86400);
 
-// URL used to check for user's country code
-pref("browser.snippets.geoUrl", "https://geo.mozilla.org/country.json");
+// URL used to check for user's country code. Please do not directly use this code or Snippets key.
+// Contact MLS team for your own credentials. https://location.services.mozilla.com/contact
+pref("browser.snippets.geoUrl", "https://location.services.mozilla.com/v1/country?key=fff72d56-b040-4205-9a11-82feda9d83a3");
 
 // URL used to ping metrics with stats about which snippets have been shown
 pref("browser.snippets.statsUrl", "https://snippets-stats.mozilla.org/mobile");
 
 // These prefs require a restart to take effect.
 pref("browser.snippets.enabled", true);
 pref("browser.snippets.syncPromo.enabled", true);
 pref("browser.snippets.firstrunHomepage.enabled", true);